@@ -59,9 +59,8 @@ adjust_dend_by_x = function(dend, leaf_pos = 1:nobs(dend)-0.5) {
             } else {
                 xl = unlist(xl)
             }
-            x = (max(xl) + min(xl))*0.5
+            x = (xl[1] + xl[length(xl)])*0.5
         }
-
         attr(d, "x") = x
         d
     })
@@ -79,7 +78,7 @@ construct_dend_segments = function(dend, gp) {
     x_is_unit = inherits(attr(dend, "x"), "unit")
     height_is_unit = inherits(attr(dend, "height"), "unit")
 
-    env = new.env()
+    env = new.env(parent = emptyenv())
     env$x0 = NULL
     env$y0 = NULL
     env$x1 = NULL
@@ -483,7 +482,7 @@ merge_dendrogram = function(x, y, only_parent = FALSE, ...) {
     od2index = NULL
     od2index[order.dendrogram(parent)] = 1:n
 
-    env = new.env()
+    env = new.env(parent = emptyenv())
     env$dend = parent
     update_dend_height_in_parent = function(ind = NULL) {
         
@@ -576,7 +575,7 @@ get_branches_heights = function(dend) {
 }
 
 "order.dendrogram<-" = function(x, value) {
-    env = new.env()
+    env = new.env(parent = emptyenv())
     env$i = 0
     dendrapply(x, function(node) {
         if(is.leaf(node)) {
@@ -595,8 +594,12 @@ print.dendrogram = function(x) {
 # can only cut dendrogram for which branches at every node are two
 cut_dendrogram = function(dend, k) {
     h = sort(dend_branches_heights(dend), decreasing = TRUE)
-    height = (h[k-1] + h[k])/2
-    trees = cut(dend, h = height)
+    if(k > length(h)) {
+        trees = cut(dend, h = 0)
+    } else {
+        height = (h[k-1] + h[k])/2
+        trees = cut(dend, h = height)
+    }
     trees
 }
 
@@ -653,7 +656,7 @@ dend_xy = function(dend) {
     if(is.null(attr(dend, "x"))) {
         dend = adjust_dend_by_x(dend)
     }
-    env = new.env()
+    env = new.env(parent = emptyenv())
     env$lt = list()
     dendrapply(dend, function(d) {
         if(is.leaf(d))
@@ -715,6 +718,8 @@ cluster_within_group = function(mat, factor) {
             order_list[[le]] = which(factor == le)[order.dendrogram(dend_list[[le]])]
             order.dendrogram(dend_list[[le]]) = order_list[[le]]
         }
+
+        attr(dend_list[[le]], ".class_label") = le
     }
 
     parent = as.dendrogram(hclust(dist(t(sapply(order_list, function(x) rowMeans(mat[, x, drop = FALSE]))))))
@@ -728,6 +733,60 @@ cluster_within_group = function(mat, factor) {
 }
 
 
+# == title
+# Cluster only between Groups
+#
+# == param
+# -mat A matrix where clustering is applied on columns.
+# -factor A categorical vector.
+#
+# == details
+# The clustering is only applied between groups and inside a group, the order is unchanged.
+#
+# == value
+# A `dendrogram` object.
+#
+# == example
+# m = matrix(rnorm(120), nc = 12)
+# colnames(m) = letters[1:12]
+# fa = rep(c("a", "b", "c"), times = c(2, 4, 6))
+# dend = cluster_between_groups(m, fa)
+# grid.dendrogram(dend, test = TRUE)
+cluster_between_groups = function(mat, factor) {
+
+    if (!is.factor(factor)) {
+        factor = factor(factor, levels = unique(factor))
+    }
+
+    dend_list = list()
+    order_list = list()
+    for(le in unique(levels(factor))) {
+        m = mat[, factor == le, drop = FALSE]
+        if (ncol(m) == 1) {
+            order_list[[le]] = which(factor == le)
+            dend_list[[le]] = structure(which(factor == le), class = "dendrogram", leaf = TRUE,
+                height = 0, label = 1, members = 1)
+        } else if(ncol(m) > 1) {
+            hc1 = hclust(dist(1:ncol(m)))
+            dend_list[[le]] = reorder(as.dendrogram(hc1), wts = 1:ncol(m), agglo.FUN = mean)
+            order_list[[le]] = which(factor == le)[order.dendrogram(dend_list[[le]])]
+            order.dendrogram(dend_list[[le]]) = order_list[[le]]
+        }
+        attr(dend_list[[le]], ".class_label") = le
+    }
+
+    parent = as.dendrogram(hclust(dist(t(sapply(order_list, function(x) rowMeans(mat[, x, drop = FALSE]))))))
+    dend_list = lapply(dend_list, function(dend) dendrapply(dend, function(node) {
+        attr(node, "height") = 0
+        node
+    }))
+    dend = merge_dendrogram(parent, dend_list)
+    order.dendrogram(dend) = unlist(order_list[order.dendrogram(parent)])
+    return(dend)
+}
+
+
+
 #######################
 dend_node_apply = function(dend, fun) {
 
@@ -759,7 +818,7 @@ dend_node_apply = function(dend, fun) {
         fun = function(d, index) fun2(d)
     }
 
-    env = new.env()
+    env = new.env(parent = emptyenv())
 
     dend_list = list(dend)
     index_list = list(NULL)
@@ -804,7 +863,7 @@ dend_node_apply = function(dend, fun) {
 dend_edit_node = function(dend, fun = function(d, index) d,
     method = c("top-bottom", "bottom-top")) {
 
-    env = new.env()
+    env = new.env(parent = emptyenv())
     env$dend = dend
 
     method = match.arg(method)
