@@ -23,6 +23,7 @@
 # -pct_gp Graphic paramters for percent values
 # -pct_digits Digits for the percent values.
 # -pct_side Side of the percent values to the oncoPrint. This argument is currently disabled.
+# -pct_include Alteration types that are included for the calculation of percent values.
 # -row_labels Labels as the row names of the oncoPrint.
 # -show_row_names Whether show row names?
 # -row_names_side Side of the row names to the oncoPrint. This argument is currently disabled.
@@ -69,6 +70,7 @@ oncoPrint = function(mat, name,
 	pct_gp = gpar(fontsize = 10), 
 	pct_digits = 0,
 	pct_side = "left",
+	pct_include = NULL,
 
 	row_labels = NULL,
 	show_row_names = TRUE,
@@ -368,7 +370,10 @@ oncoPrint = function(mat, name,
 	}
 
 	# for each gene, percent of samples that have alterations
-	pct_num = rowSums(apply(arr, 1:2, any)) / ncol(mat_list[[1]])
+	if(is.null(pct_include)) {
+		pct_include = dimnames(arr)[[3]]
+	}
+	pct_num = rowSums(apply(arr[, , dimnames(arr)[[3]] %in% pct_include, drop = FALSE], 1:2, any)) / ncol(mat_list[[1]])
 	pct = paste0(round(pct_num * 100, digits = pct_digits), "%")
 
 	### now the annotations
@@ -562,9 +567,11 @@ oncoPrint = function(mat, name,
 
 			# adjust order of alter_fun3 with at
 			if(!is.null(heatmap_legend_param$at)) {
-				if(length(setdiff(heatmap_legend_param$at, names(alter_fun3))) == 0) {
-					alter_fun3 = alter_fun3[heatmap_legend_param$at]
-				}
+				ind = which(heatmap_legend_param$at %in% names(alter_fun3))
+				heatmap_legend_param$at = heatmap_legend_param$at[ind]
+				heatmap_legend_param$labels = heatmap_legend_param$labels[ind]
+
+				alter_fun3 = alter_fun3[heatmap_legend_param$at]
 			}
 
 			heatmap_legend_param$graphics = alter_fun3
