@@ -55,6 +55,12 @@
 # -silent Not supported.
 # -na_col The same as in `pheatmap::pheatmap`.
 # -name Name of the heatmap. This argument is passed to `Heatmap`.
+# -fontfamily Font family for row and column names.
+# -fontfamily_row Font family for row names.
+# -fontfamily_col Font family for column names.
+# -fontface Font face for row and column names.
+# -fontface_row Font face for row names.
+# -fontface_col Font face for column names.
 # -heatmap_legend_param  Pass to `Heatmap`.
 # -... Other arguments passed to `Heatmap`.
 # -run_draw Whether to run ``draw()`` function to the heatmap object.
@@ -121,6 +127,14 @@ pheatmap = function(mat,
     na_col = "#DDDDDD", 
     name = NULL,
 
+    # other graphic parameters for fonts
+    fontfamily = "",
+    fontfamily_row = fontfamily,
+    fontfamily_col = fontfamily,
+    fontface = 1,
+    fontface_row = fontface,
+    fontface_col = fontface,
+
     # argument specific for Heatmap()
     heatmap_legend_param = list(),
     ...,
@@ -171,9 +185,9 @@ pheatmap = function(mat,
             n_col = length(color)
             if(identical(scale, "row") || identical(scale, "column")) {
                 lim = max(abs(mat), na.rm = TRUE)
-                ht_param$col = colorRamp2(seq(-lim, lim, length = n_col), color)
+                ht_param$col = colorRamp2(seq(-lim, lim, length.out = n_col), color)
             } else {
-                ht_param$col = colorRamp2(seq(min(mat, na.rm = TRUE), max(mat, na.rm = TRUE), length = n_col), color)
+                ht_param$col = colorRamp2(seq(min(mat, na.rm = TRUE), max(mat, na.rm = TRUE), length.out = n_col), color)
             }
         } else  {
             if(length(breaks) == length(color) + 1) {
@@ -201,7 +215,7 @@ pheatmap = function(mat,
                 ht_param$col = colorRamp2(breaks, color)
             } else {
                 n_col = length(color)
-                ht_param$col  = colorRamp2(seq(min(breaks), max(breaks), length = n_col), color)
+                ht_param$col  = colorRamp2(seq(min(breaks), max(breaks), length.out = n_col), color)
                 warning_wrap("`breaks` does not have the same length as `color`. The colors are interpolated from the minimal to the maximal of `breaks`.")
             }
         }
@@ -271,7 +285,7 @@ pheatmap = function(mat,
 
     if(identical(scale, "row") || identical(scale, "column")) {
         if(identical(legend_breaks, NA)) {
-            lim = quantile(abs(mat), 0.975)
+            lim = quantile(abs(mat), 0.975, na.rm = TRUE)
 
             le = pretty(c(-lim, lim), n = 3)
             if(length(le) == 7 && le[1] == -3) {
@@ -311,7 +325,7 @@ pheatmap = function(mat,
                 if(is.null(names(annotation_colors[[nm]])) && is.numeric(annotation_col[, nm])) {
                     foo_x = annotation_col[, nm]
                     foo_n_col = length(annotation_colors[[nm]])
-                    annotation_colors[[nm]] = colorRamp2(seq(min(foo_x), max(foo_x), length = foo_n_col), annotation_colors[[nm]])
+                    annotation_colors[[nm]] = colorRamp2(seq(min(foo_x), max(foo_x), length.out = foo_n_col), annotation_colors[[nm]])
                 }
             }
         }
@@ -339,7 +353,7 @@ pheatmap = function(mat,
                 if(is.null(names(annotation_colors[[nm]])) && is.numeric(annotation_row[, nm])) {
                     foo_x = annotation_row[, nm]
                     foo_n_col = length(annotation_colors[[nm]])
-                    annotation_colors[[nm]] = colorRamp2(seq(min(foo_x), max(foo_x), length = foo_n_col), annotation_colors[[nm]])
+                    annotation_colors[[nm]] = colorRamp2(seq(min(foo_x), max(foo_x), length.out = foo_n_col), annotation_colors[[nm]])
                 }
             }
         }
@@ -361,8 +375,8 @@ pheatmap = function(mat,
     ht_param$show_row_names = show_rownames
     ht_param$show_column_names = show_colnames
     
-    ht_param$row_names_gp = gpar(fontsize = fontsize_row)
-    ht_param$column_names_gp = gpar(fontsize = fontsize_col)
+    ht_param$row_names_gp = gpar(fontsize = fontsize_row, fontfamily = fontfamily_row, fontface = fontface_row)
+    ht_param$column_names_gp = gpar(fontsize = fontsize_col, fontfamily = fontfamily_col, fontface = fontface_col)
 
     angle_col = match.arg(angle_col)[1]
     angle_col = switch(angle_col, 
