@@ -15,3 +15,8 @@ cm = ColorMapping(name = "test",
 	colors = c("blue", "white", "red"),
 	levels = c(1, 2, 3))
 color_mapping_legend(cm)
+
+ha = SingleAnnotation(value = rep(NA, 10), name = "foo")
+cm = ha@color_mapping
+color_mapping_legend(cm)
+
